Transform position from a fixed Cartesian NED frame to ellipsoidal coordinates
Value
An object of class trajectory in "ellipsoidal" system or a matrix of position data with latitude, longitude, and altitude, according to the type of input x
Examples
data("example_1_traj_ned")
traj_ned <- make_trajectory(example_1_traj_ned, system = "ned")
plot(traj_ned)
traj_ellips <- X_ned2ellips(traj_ned, x_o = example_1_traj_ellipsoidal[1, -1])
plot(traj_ellips, threeD = FALSE)
plot(traj_ellips, threeD = TRUE)