Construct a timing object controlling the timing and frequencies for navigation, making sure about the consistency and feasibility of provided information.
Usage
make_timing(
nav.start = NULL,
nav.end = NULL,
freq.imu = NULL,
freq.gps = NULL,
freq.baro = NULL,
gps.out.start = NULL,
gps.out.end = NULL
)Arguments
Time at which navigation starts
Time at which navigation ends
- freq.imu
Frequency of generated IMU data (and hence that of navigation)
- freq.gps
Frequency of generated GPS data
- freq.baro
Frequency of generated Baro data
- gps.out.start
Time at which GPS outage starts
- gps.out.end
Time at which GPS outage ends